@@ -14,8 +14,9 @@ import logging
 from uuid import uuid4
 from .socket_response import ensure_socket_response
 from datetime import datetime
-
 from . import log_conf
+import json
+
 log_conf.init()
 
 
@@ -31,7 +32,7 @@ class Node(FastAPI):
         self.ws_url = f'ws{"s" if host != "backend" else ""}://' + host
 
         self.name = name
-        self.uuid = self.read_or_create_uuid() if uuid is None else uuid
+        self.uuid = self.read_or_create_uuid(self.name) if uuid is None else uuid
         self.startup_time = datetime.now()
 
         self.sio_client = socketio.AsyncClient(
@@ -60,16 +61,20 @@ class Node(FastAPI):
 
         self.register_lifecycle_events()
 
-    def read_or_create_uuid(self) -> str:
-        if not os.path.exists(f'{GLOBALS.data_folder}/uuid.txt'):
-            os.makedirs(GLOBALS.data_folder, exist_ok=True)
-            uuid = str(uuid4())
-            with open(f'{GLOBALS.data_folder}/uuid.txt', 'a+') as f:
-                f.write(uuid)
-        else:
-            with open(f'{GLOBALS.data_folder}/uuid.txt', 'r') as f:
-                uuid = f.read()
+    def read_or_create_uuid(self, identifier: str) -> str:
+        identifier = identifier.lower().replace(' ', '_')
+        uuids = {}
+        file_path = f'{GLOBALS.data_folder}/uuids.json'
+        if os.path.exists(file_path):
+            with open(file_path, 'r') as f:
+                uuids = json.load(f)
 
+        uuid = uuids.get(identifier, None)
+        if not uuid:
+            uuid = str(uuid4())
+            uuids[identifier] = uuid
+            with open(file_path, 'w') as f:
+                json.dump(uuids, f)
         return uuid
 
     def register_lifecycle_events(self):
@@ -105,6 +110,7 @@ class Node(FastAPI):
         logging.info(f'connecting to Learning Loop at {self.ws_url}')
         try:
             headers = await self.get_sio_headers()
+            logging.info(f'headers: {headers}')
             await self.sio_client.connect(f"{self.ws_url}", headers=headers, socketio_path="/ws/socket.io")
             logging.debug(f'my sid is {self.sio_client.sid}')
             logging.debug(f"connecting as type {headers['nodeType']}")
